@@ -6,6 +6,7 @@ local_gtfs_path <- system.file("extdata",
                                "google_transit_nyc_subway.zip", 
                                package = "tidytransit")
 
+
 working <- function() {
   connecting <- function(gtfs_example_url) {
     r <- base::try(httr::GET(gtfs_example_url, httr::timeout(5)))
@@ -17,7 +18,7 @@ working <- function() {
 test_that("read_gtfs() imports a local file to a 
           list of dataframes and doesnt 
           delete the source file", {
-  gtfs_obj <- tidytransit:::read_gtfs(local_gtfs_path)
+  gtfs_obj <- read_gtfs(local_gtfs_path)
   
   expect_is(gtfs_obj, "gtfs")
   file.exists(local_gtfs_path)
@@ -25,54 +26,16 @@ test_that("read_gtfs() imports a local file to a
 
 test_that("loud read_gtfs", {
   expect_is(
-    tidytransit:::read_gtfs(local_gtfs_path, quiet = FALSE),
+    read_gtfs(local_gtfs_path, quiet = FALSE),
     "gtfs")
 })
 
-test_that("Downloading a zip file from a gtfs_example_url returns a file", {
-  skip_on_cran()
-  if(!working()){
-    skip("no internet, skipping")
-  }
-  else {  
-  zip <- tidytransit:::download_from_url(gtfs_example_url, quiet = T)
-
-  expect_true(file.exists(zip))
-  }
-})
-
 test_that("import-bad paths throw good errors", {
   skip_on_cran()
   not_a_url <- "#!:D"
   expect_error(read_gtfs(path)) # invalid path
 })
 
-test_that("import-empty txt files are not 
-          imported and non-empty ones are imported", {
-  skip_on_cran()
-  if(!working()){
-    skip("no internet, skipping")
-  }
-  else {
-    zip <- tidytransit:::download_from_url(gtfs_example_url, quiet = T)
-    folder <- tidytransit:::unzip_file(zip)
-    files <- list.files(folder, full.names = TRUE)
-    agency_file <- files[1]
-    # empty file
-    empty <- ""
-    write(empty, file.path(folder, "_empty.txt"))
-    files <- list.files(folder, full.names = TRUE)
-    empty_file <- files[1]
-    
-    expect_null(
-      tidytransit:::parse_gtfs_file("_empty", 
-                                    empty_file))
-    expect_is(
-      tidytransit:::parse_gtfs_file("agency", 
-                                    agency_file), "tbl_df") 
-  }
-})
-
 test_that("the read_gtfs function works", {
   skip_on_cran()
   if(!working()){
@@ -96,8 +59,8 @@ test_that("the read_gtfs function fails gracefully on bad urls", {
     bad_url <- "https://developers.google.com/transit/gtfs/examples/sample-feed-bad.zip"
   
     # non-specified path
-    expect_error(tidytransit::read_gtfs(not_zip, quiet=TRUE))
-    expect_error(tidytransit::read_gtfs(bad_url, quiet=TRUE)) # not zip file warning
+    expect_error(read_gtfs(not_zip, quiet=TRUE))
+    expect_error(read_gtfs(bad_url, quiet=TRUE)) # not zip file warning
   }
   
 })
@@ -105,7 +68,7 @@ test_that("the read_gtfs function fails gracefully on bad urls", {
 test_that("Some minimal validation is performed and returned", {
   skip_on_cran()
   if(working()){
-    gtfs_obj1 <- tidytransit::read_gtfs(gtfs_example_url)
+    gtfs_obj1 <- read_gtfs(gtfs_example_url)
     
     expect_true(dim(attributes(gtfs_obj1)$validation_result)[1]>0)
     expect_true(dim(attributes(gtfs_obj1)$validation_result)[2]>0)
@@ -113,8 +76,8 @@ test_that("Some minimal validation is performed and returned", {
 })
 
 test_that("unknown local file throws meaningful error", {
-  tidytransit::read_gtfs(local_gtfs_path)
-  expect_error(tidytransit::read_gtfs("/Users/wrong.zip"))
+  read_gtfs(local_gtfs_path)
+  expect_error(read_gtfs("/Users/wrong.zip"))
 })
 
 test_that("Files with BOM can be read", {
@@ -122,18 +85,18 @@ test_that("Files with BOM can be read", {
   bom_path <- system.file("extdata", 
               "sample-feed-bom.zip", 
               package = "tidytransit")
-  g <- tidytransit::read_gtfs(bom_path)
+  g <- read_gtfs(bom_path)
   expect_true(is_gtfs_obj(g))
 })
 
 test_that("Feed with additional data can be read", {
   g_plus_path <- system.file("extdata", "sample-feed-plus.zip", package = "tidytransit")
-  g <- tidytransit::read_gtfs(g_plus_path, F)
+  g <- read_gtfs(g_plus_path)
   expect_true(is_gtfs_obj(g))
 })
 
 test_that("validation", {
   g_invalid_path = system.file("extdata","sample-feed-invalid.zip", package = "tidytransit")
   expect_warning(read_gtfs(g_invalid_path), "Invalid feed. Missing required file(s): stop_times", fixed = TRUE)
-  expect_warning(read_gtfs(g_invalid_path), "Invalid feed. Missing required field(s): stop_id", fixed = TRUE)
+  expect_warning(read_gtfs(g_invalid_path), "Invalid feed. Missing required field(s) in stops: stop_id", fixed = TRUE)
 })
